@@ -40,6 +40,8 @@
 #include <winsock2.h>
 # ifdef HAVE_WS2TCPIP_H
 #  include <ws2tcpip.h>
+// fix for MingW not defining IPV6_V6ONLY
+#  define IPV6_V6ONLY 27
 # endif
 # ifdef HAVE_WSPIAPI_H
 #  include <wspiapi.h>
@@ -174,7 +176,7 @@ hsnet_freeaddrinfo(struct addrinfo *ai)
 }
 #endif
 
-#if defined(HAVE_WINSOCK_H) && !defined(cygwin32_HOST_OS)
+#if defined(HAVE_WINSOCK2_H) && !defined(cygwin32_HOST_OS)
 # define WITH_WINSOCK  1
 #endif
 
